@@ -35,7 +35,14 @@
 #include <memory> // for unique_ptr
 #include <unordered_map>
 #include <cassert>
+
+#ifndef GEOS_DEBUG
+#define GEOS_DEBUG 0
+#endif
+
+#if GEOS_DEBUG
 #include <iostream>
+#endif
 
 using namespace geos::geom;
 
@@ -138,7 +145,7 @@ LineStringTransformer::transformCoordinates(
     const CoordinateSequence* coords,
     const Geometry* parent)
 {
-#ifdef GEOS_DEBUG
+#if GEOS_DEBUG
     cpp_compat_cerr << __FUNCTION__ << ": parent: " << parent
               << std::endl;
 #endif
@@ -147,7 +154,7 @@ LineStringTransformer::transformCoordinates(
         assert(it != linestringMap.end());
 
         TaggedLineString* taggedLine = it->second;
-#ifdef GEOS_DEBUG
+#if GEOS_DEBUG
         cpp_compat_cerr << "LineStringTransformer[" << this << "] "
                   << " getting result Coordinates from "
                   << " TaggedLineString[" << taggedLine << "]"
@@ -225,7 +232,7 @@ LineStringMapBuilderFilter::filter_ro(const Geometry* geom)
 
     if(const LineString* ls =
                 dynamic_cast<const LineString*>(geom)) {
-        int minSize = ls->isClosed() ? 4 : 2;
+        std::size_t minSize = ls->isClosed() ? 4 : 2;
         taggedLine = new TaggedLineString(ls, minSize);
     }
     else {
@@ -234,11 +241,8 @@ LineStringMapBuilderFilter::filter_ro(const Geometry* geom)
 
     // Duplicated Geometry pointers shouldn't happen
     if(! linestringMap.insert(std::make_pair(geom, taggedLine)).second) {
-        cpp_compat_cerr << __FILE__ << ":" << __LINE__
-                  << "Duplicated Geometry components detected"
-                  << std::endl;
-
         delete taggedLine;
+        throw util::GEOSException("Duplicated Geometry components detected");
     }
 }
 
@@ -296,7 +300,7 @@ TopologyPreservingSimplifier::getResultGeometry()
         LineStringMapBuilderFilter lsmbf(linestringMap);
         inputGeom->apply_ro(&lsmbf);
 
-#ifdef GEOS_DEBUG
+#if GEOS_DEBUG
         cpp_compat_cerr << "LineStringMapBuilderFilter applied, "
                   << " lineStringMap contains "
                   << linestringMap.size() << " elements\n";
@@ -307,14 +311,14 @@ TopologyPreservingSimplifier::getResultGeometry()
         lineSimplifier->simplify(begin, end);
 
 
-#ifdef GEOS_DEBUG
+#if GEOS_DEBUG
         cpp_compat_cerr << "all TaggedLineString simplified\n";
 #endif
 
         LineStringTransformer trans(linestringMap);
         result = trans.transform(inputGeom);
 
-#ifdef GEOS_DEBUG
+#if GEOS_DEBUG
         cpp_compat_cerr << "inputGeom transformed\n";
 #endif
 
@@ -339,7 +343,7 @@ TopologyPreservingSimplifier::getResultGeometry()
         delete it->second;
     }
 
-#ifdef GEOS_DEBUG
+#if GEOS_DEBUG
     cpp_compat_cerr << "returning result\n";
 #endif
 
